@@ -14,6 +14,8 @@ use Exporter;
 our @ISA = 'Exporter';
 our @EXPORT = '%options';
 
+(our $VERSION) = q($Revision: 271299 $) =~ /(\d+)/;
+
 # The program that invokes us
 (my $tool = $0) =~ s!.*/!!;
 
@@ -124,7 +126,6 @@ my %options_spec = (
 	'no-suggests' => sub { $urpm->{options}{'no-suggests'} = 1 },
 	'allow-nodeps' => sub { $urpm->{options}{'allow-nodeps'} = 1 },
 	'allow-force' => sub { $urpm->{options}{'allow-force'} = 1 },
-	'downgrade' => sub { $urpm->{options}{downgrade} = 1 },
 	'parallel=s' => \$::parallel,
 
 	'metalink!' => sub { $urpm->{options}{metalink} = $_[1] },
@@ -167,16 +168,10 @@ my %options_spec = (
 	'norebuild!' => sub { $urpm->{options}{'build-hdlist-on-error'} = !$_[1] },
 	'test!' => \$::test,
 	'debug__do_not_install' => \$options{debug__do_not_install},
-	deploops => \$options{deploops},
 	'skip=s' => \$options{skip},
 	'prefer=s' => \$options{prefer},
  	'root=s' => sub { set_root($urpm, $_[1]) },
-	'use-distrib=s' => sub {
-	    $options{usedistrib} = $_[1];
-	    return if !$>;
-	    $urpm->{cachedir} = $urpm->valid_cachedir;
-	    $urpm->{statedir} = $urpm->valid_statedir;
-	},
+	'use-distrib=s' => \$options{usedistrib},
 	'probe-synthesis' => sub { $options{probe_with} = 'synthesis' },
 	'probe-hdlist' => sub { $options{probe_with} = 'synthesis' }, #- ignored, kept for compatibility
 	'excludepath|exclude-path=s' => sub { $urpm->{options}{excludepath} = $_[1] },
@@ -185,6 +180,7 @@ my %options_spec = (
 	'ignorearch' => sub { $urpm->{options}{ignorearch} = 1 },
 	noscripts => sub { $urpm->{options}{noscripts} = 1 },
 	replacefiles => sub { $urpm->{options}{replacefiles} = 1 },
+	repackage => sub { $urpm->{options}{repackage} = 1 },
 	'more-choices' => sub { $urpm->{options}{morechoices} = 1 },
 	'expect-install!' => \$::urpm::main_loop::expect_install,
 	'nolock' => \$options{nolock},
@@ -358,6 +354,16 @@ my %options_spec = (
 	'verify-rpm!' => sub { ${options}{'verify-rpm'} = $_[1] },
     },
 
+    'urpmi.recover' => {
+	'list=s' => \$::listdate,
+	'list-all' => sub { $::listdate = -1 },
+	'list-safe' => sub { $::listdate = 'checkpoint' },
+	checkpoint => \$::do_checkpoint,
+	'rollback=s' => \$::rollback,
+	noclean => \$::noclean,
+	disable => \$::disable,
+    },
+
 );
 
 # generate urpmf options callbacks
@@ -413,7 +419,7 @@ foreach my $k ('allow-medium-change', 'auto', 'auto-select', 'clean', 'download-
 $options_spec{gurpmi2} = $options_spec{gurpmi};
 
 foreach my $k ("test!", "force", "root=s", "use-distrib=s", 'env=s',
-    'noscripts', 'auto', 'auto-orphans', 'justdb',
+    'repackage', 'noscripts', 'auto', 'auto-orphans', 'justdb',
     "parallel=s")
 {
     $options_spec{urpme}{$k} = $options_spec{urpmi}{$k};
